package
Version:
v0.0.0-...-be48527
Opens a new window with list of versions in this module.
Published: Aug 31, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package provider 定义配置解码抽象接口,用于解耦 pkg 层对 viper 的直接依赖。
type Provider interface {
Unmarshal(obj any) error
}
Provider 抽象配置解码能力。
pkg/server 和 pkg/client 通过此接口从任何配置源(Viper、map、JSON 等)加载配置。
type Refresher interface {
Refresh() error
}
Refresher 是可选的配置重载接口,用于 SIGHUP 信号重新读取配置文件。
Source Files
¶
Click to show internal directories.
Click to hide internal directories.